pub enum AttrStyle {
Outer,
Inner(Bang),
}Distinguishes between attributes that decorate an item and attributes
that are contained within an item.
This type is available only if Syn is built with the "derive" or "full"
feature.
#[repr(transparent)]
/// # Example
/** Please file an issue */
#![feature(proc_macro)]
//! # Example
/*! Please file an issue */
Formats the value using the given formatter. Read more
fn eq(&self, other: &Self) -> bool[src]
This method tests for self and other values to be equal, and is used
by ==. Read more
#[must_use]
pub fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.